# `narwhals.Series`

::: narwhals.series.Series
    handler: python
    options:
      members:
        - alias
        - all
        - any
        - cast
        - drop_nulls
        - dtype
        - filter
        - is_between
        - is_in
        - is_null
        - max
        - mean
        - min
        - name
        - n_unique
        - sample
        - shape
        - sort
        - std
        - sum
        - to_numpy
        - to_pandas
        - unique
      show_source: false
      show_bases: false
